==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/keyvault/kotlin/outputs/SystemDataResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.keyvault.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Metadata pertaining to creation and last modification of the key vault resource.
 * @property createdAt The timestamp of the key vault resource creation (UTC).
 * @property createdBy The identity that created the key vault resource.
 * @property createdByType The type of identity that created the key vault resource.
 * @property lastModifiedAt The timestamp of the key vault resource last modification (UTC).
 * @property lastModifiedBy The identity that last modified the key vault resource.
 * @property lastModifiedByType The type of identity that last modified the key vault resource.
 */
public data class SystemDataResponse(
    public val createdAt: String? = null,
    public val createdBy: String? = null,
    public val createdByType: String? = null,
    public val lastModifiedAt: String? = null,
    public val lastModifiedBy: String? = null,
    public val lastModifiedByType: String? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.keyvault.outputs.SystemDataResponse):
            SystemDataResponse = SystemDataResponse(
            createdAt = javaType.createdAt().map({ args0 -> args0 }).orElse(null),
            createdBy = javaType.createdBy().map({ args0 -> args0 }).orElse(null),
            createdByType = javaType.createdByType().map({ args0 -> args0 }).orElse(null),
            lastModifiedAt = javaType.lastModifiedAt().map({ args0 -> args0 }).orElse(null),
            lastModifiedBy = javaType.lastModifiedBy().map({ args0 -> args0 }).orElse(null),
            lastModifiedByType = javaType.lastModifiedByType().map({ args0 -> args0 }).orElse(null),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/keyvault/kotlin/outputs/SystemDataResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.keyvault.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Metadata pertaining to creation and last modification of the key vault resource.
 * @property createdAt The timestamp of the key vault resource creation (UTC).
 * @property createdBy The identity that created the key vault resource.
 * @property createdByType The type of identity that created the key vault resource.
 * @property lastModifiedAt The timestamp of the key vault resource last modification (UTC).
 * @property lastModifiedBy The identity that last modified the key vault resource.
 * @property lastModifiedByType The type of identity that last modified the key vault resource.
 */
public data class SystemDataResponse(
    public val createdAt: String? = null,
    public val createdBy: String? = null,
    public val createdByType: String? = null,
    public val lastModifiedAt: String? = null,
    public val lastModifiedBy: String? = null,
    public val lastModifiedByType: String? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.keyvault.outputs.SystemDataResponse): SystemDataResponse = SystemDataResponse(
            createdAt = javaType.createdAt().map({ args0 -> args0 }).orElse(null),
            createdBy = javaType.createdBy().map({ args0 -> args0 }).orElse(null),
            createdByType = javaType.createdByType().map({ args0 -> args0 }).orElse(null),
            lastModifiedAt = javaType.lastModifiedAt().map({ args0 -> args0 }).orElse(null),
            lastModifiedBy = javaType.lastModifiedBy().map({ args0 -> args0 }).orElse(null),
            lastModifiedByType = javaType.lastModifiedByType().map({ args0 -> args0 }).orElse(null),
        )
    }
}
